summaryrefslogtreecommitdiff
path: root/libs/surfaces/osc/osc.cc
diff options
context:
space:
mode:
authorLen Ovens <len@ovenwerks.net>2018-07-06 07:34:44 -0700
committerLen Ovens <len@ovenwerks.net>2018-07-06 07:35:24 -0700
commitc2af992ac7690a1bab281b2245ffadc041b4916e (patch)
treea411184718faaebf5b5a37ebc2ae59a534c9c8b4 /libs/surfaces/osc/osc.cc
parentfc69b29c885245fff53b5c0f4117b9fbc5de7344 (diff)
OSC: Use spill instead of collect
Diffstat (limited to 'libs/surfaces/osc/osc.cc')
-rw-r--r--libs/surfaces/osc/osc.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/libs/surfaces/osc/osc.cc b/libs/surfaces/osc/osc.cc
index 9c0e8e7d32..97fd70c51d 100644
--- a/libs/surfaces/osc/osc.cc
+++ b/libs/surfaces/osc/osc.cc
@@ -835,8 +835,8 @@ OSC::catchall (const char *path, const char* types, lo_arg **argv, int argc, lo_
ret = touch_detect (path, types, argv, argc, msg);
} else
- if (strstr (path, X_("/collect"))) {
- ret = collect (path, types, argv, argc, msg);
+ if (strstr (path, X_("/spill"))) {
+ ret = spill (path, types, argv, argc, msg);
} else
if (len >= 17 && !strcmp (&path[len-15], X_("/#current_value"))) {
@@ -3942,12 +3942,12 @@ OSC::fake_touch (boost::shared_ptr<ARDOUR::AutomationControl> ctrl)
}
int
-OSC::collect (const char *path, const char* types, lo_arg **argv, int argc, lo_message msg)
+OSC::spill (const char *path, const char* types, lo_arg **argv, int argc, lo_message msg)
{
/*
* collect should have the form of:
* /select/collect (may have i or f keypress/release)
* /strip/collect i (may have keypress and i may be inline)
*/
if (!session || argc > 1) return -1;
@@ -3942,12 +3942,12 @@ OSC::fake_touch (boost::shared_ptr<ARDOUR::AutomationControl> ctrl)
{
/*
- * collect should have the form of:
- * /select/collect (may have i or f keypress/release)
- * /strip/collect i (may have keypress and i may be inline)
+ * spill should have the form of:
+ * /select/spill (may have i or f keypress/release)
+ * /strip/spill i (may have keypress and i may be inline)
*/
if (!session || argc > 1) return -1;